@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -42,8 +47,8 @@
 #include <QPainter>
 #include <QEvent>
 
-class QPushButton;
-class QRadioButton;
+QT_FORWARD_DECLARE_CLASS(QPushButton)
+QT_FORWARD_DECLARE_CLASS(QRadioButton)
 
 #ifdef QT_OPENGL_SUPPORT
 #include <QtOpenGL>
@@ -74,6 +79,19 @@ private:
     QRadioButton *rbSourceAtop;
     QRadioButton *rbDestAtop;
     QRadioButton *rbXor;
+
+    QRadioButton *rbPlus;
+    QRadioButton *rbMultiply;
+    QRadioButton *rbScreen;
+    QRadioButton *rbOverlay;
+    QRadioButton *rbDarken;
+    QRadioButton *rbLighten;
+    QRadioButton *rbColorDodge;
+    QRadioButton *rbColorBurn;
+    QRadioButton *rbHardLight;
+    QRadioButton *rbSoftLight;
+    QRadioButton *rbDifference;
+    QRadioButton *rbExclusion;
 };
 
 class CompositionRenderer : public ArthurFrame
@@ -95,7 +113,7 @@ public:
     void mouseMoveEvent(QMouseEvent *);
     void mouseReleaseEvent(QMouseEvent *);
 
-    void setCirclePos(const QPointF &pos) { m_circle_pos = pos; update(); }
+    void setCirclePos(const QPointF &pos);
 
     QSize sizeHint() const { return QSize(500, 400); }
 
@@ -104,7 +122,7 @@ public:
     int circleAlpha() const { return m_circle_alpha; }
 
 public slots:
-void setClearMode() { m_composition_mode = QPainter::CompositionMode_Clear; update(); }
+    void setClearMode() { m_composition_mode = QPainter::CompositionMode_Clear; update(); }
     void setSourceMode() { m_composition_mode = QPainter::CompositionMode_Source; update(); }
     void setDestMode() { m_composition_mode = QPainter::CompositionMode_Destination; update(); }
     void setSourceOverMode() { m_composition_mode = QPainter::CompositionMode_SourceOver; update(); }
@@ -117,6 +135,19 @@ void setClearMode() { m_composition_mode = QPainter::CompositionMode_Clear; upda
     void setDestAtopMode() { m_composition_mode = QPainter::CompositionMode_DestinationAtop; update(); }
     void setXorMode() { m_composition_mode = QPainter::CompositionMode_Xor; update(); }
 
+    void setPlusMode() { m_composition_mode = QPainter::CompositionMode_Plus; update(); }
+    void setMultiplyMode() { m_composition_mode = QPainter::CompositionMode_Multiply; update(); }
+    void setScreenMode() { m_composition_mode = QPainter::CompositionMode_Screen; update(); }
+    void setOverlayMode() { m_composition_mode = QPainter::CompositionMode_Overlay; update(); }
+    void setDarkenMode() { m_composition_mode = QPainter::CompositionMode_Darken; update(); }
+    void setLightenMode() { m_composition_mode = QPainter::CompositionMode_Lighten; update(); }
+    void setColorDodgeMode() { m_composition_mode = QPainter::CompositionMode_ColorDodge; update(); }
+    void setColorBurnMode() { m_composition_mode = QPainter::CompositionMode_ColorBurn; update(); }
+    void setHardLightMode() { m_composition_mode = QPainter::CompositionMode_HardLight; update(); }
+    void setSoftLightMode() { m_composition_mode = QPainter::CompositionMode_SoftLight; update(); }
+    void setDifferenceMode() { m_composition_mode = QPainter::CompositionMode_Difference; update(); }
+    void setExclusionMode() { m_composition_mode = QPainter::CompositionMode_Exclusion; update(); }
+
     void setCircleAlpha(int alpha) { m_circle_alpha = alpha; update(); }
     void setCircleColor(int hue) { m_circle_hue = hue; update(); }
     void setAnimationEnabled(bool enabled) { m_animation_enabled = enabled; update(); }
@@ -128,9 +159,15 @@ private:
 
     QPainter::CompositionMode m_composition_mode;
 
+#ifdef Q_WS_QWS
+    QPixmap m_image;
+    QPixmap m_buffer;
+    QPixmap m_base_buffer;
+#else
     QImage m_image;
     QImage m_buffer;
     QImage m_base_buffer;
+#endif
 
     int m_circle_alpha;
     int m_circle_hue;
