@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -58,6 +56,7 @@
 #include <QPainterPath>
 #include <QPushButton>
 #include <QHBoxLayout>
+#include <QBitmap>
 #include <QtDebug>
 
 #undef DEBUG_SIZEHINTS
@@ -507,6 +506,15 @@ void ColorSwatch::contextMenuEvent(QContextMenuEvent *event)
     menu->exec(event->globalPos());
 }
 
+void ColorSwatch::resizeEvent(QResizeEvent *e)
+{
+    if (BlueTitleBar *btb = qobject_cast<BlueTitleBar*>(titleBarWidget()))
+        btb->updateMask();
+
+    QDockWidget::resizeEvent(e);
+}
+
+
 void ColorSwatch::allow(Qt::DockWidgetArea area, bool a)
 {
     Qt::DockWidgetAreas areas = allowedAreas();
@@ -584,4 +592,155 @@ void ColorSwatch::changeVerticalTitleBar(bool on)
                     : features() & ~DockWidgetVerticalTitleBar);
 }
 
+QSize BlueTitleBar::minimumSizeHint() const
+{
+    QDockWidget *dw = qobject_cast<QDockWidget*>(parentWidget());
+    Q_ASSERT(dw != 0);
+    QSize result(leftPm.width() + rightPm.width(), centerPm.height());
+    if (dw->features() & QDockWidget::DockWidgetVerticalTitleBar)
+        result.transpose();
+    return result;
+}
+
+BlueTitleBar::BlueTitleBar(QWidget *parent)
+    : QWidget(parent)
+{
+    leftPm = QPixmap(":/res/titlebarLeft.png");
+    centerPm = QPixmap(":/res/titlebarCenter.png");
+    rightPm = QPixmap(":/res/titlebarRight.png");
+}
+
+void BlueTitleBar::paintEvent(QPaintEvent*)
+{
+    QPainter painter(this);
+    QRect rect = this->rect();
+
+    QDockWidget *dw = qobject_cast<QDockWidget*>(parentWidget());
+    Q_ASSERT(dw != 0);
+
+    if (dw->features() & QDockWidget::DockWidgetVerticalTitleBar) {
+        QSize s = rect.size();
+        s.transpose();
+        rect.setSize(s);
+
+        painter.translate(rect.left(), rect.top() + rect.width());
+        painter.rotate(-90);
+        painter.translate(-rect.left(), -rect.top());
+    }
+
+    painter.drawPixmap(rect.topLeft(), leftPm);
+    painter.drawPixmap(rect.topRight() - QPoint(rightPm.width() - 1, 0), rightPm);
+    QBrush brush(centerPm);
+    painter.fillRect(rect.left() + leftPm.width(), rect.top(),
+                        rect.width() - leftPm.width() - rightPm.width(),
+                        centerPm.height(), centerPm);
+}
+
+void BlueTitleBar::mousePressEvent(QMouseEvent *event)
+{
+    QPoint pos = event->pos();
+
+    QRect rect = this->rect();
+
+    QDockWidget *dw = qobject_cast<QDockWidget*>(parentWidget());
+    Q_ASSERT(dw != 0);
+
+    if (dw->features() & QDockWidget::DockWidgetVerticalTitleBar) {
+        QPoint p = pos;
+        pos.setX(rect.left() + rect.bottom() - p.y());
+        pos.setY(rect.top() + p.x() - rect.left());
+
+        QSize s = rect.size();
+        s.transpose();
+        rect.setSize(s);
+    }
+
+    const int buttonRight = 7;
+    const int buttonWidth = 20;
+    int right = rect.right() - pos.x();
+    int button = (right - buttonRight)/buttonWidth;
+    switch (button) {
+        case 0:
+            event->accept();
+            dw->close();
+            break;
+        case 1:
+            event->accept();
+            dw->setFloating(!dw->isFloating());
+            break;
+        case 2: {
+            event->accept();
+            QDockWidget::DockWidgetFeatures features = dw->features();
+            if (features & QDockWidget::DockWidgetVerticalTitleBar)
+                features &= ~QDockWidget::DockWidgetVerticalTitleBar;
+            else
+                features |= QDockWidget::DockWidgetVerticalTitleBar;
+            dw->setFeatures(features);
+            break;
+        }
+        default:
+            event->ignore();
+            break;
+    }
+}
+
+void BlueTitleBar::updateMask()
+{
+    QDockWidget *dw = qobject_cast<QDockWidget*>(parent());
+    Q_ASSERT(dw != 0);
+
+    QRect rect = dw->rect();
+    QPixmap bitmap(dw->size());
+
+    {
+        QPainter painter(&bitmap);
+
+        ///initialize to transparent
+        painter.fillRect(rect, Qt::color0);
+
+        QRect contents = rect;
+        contents.setTopLeft(geometry().bottomLeft());
+        contents.setRight(geometry().right());
+        contents.setBottom(contents.bottom()-y());
+        painter.fillRect(contents, Qt::color1);
+
+
+
+        //let's pait the titlebar
+
+        QRect titleRect = this->geometry();
+
+        if (dw->features() & QDockWidget::DockWidgetVerticalTitleBar) {
+            QSize s = rect.size();
+            s.transpose();
+            rect.setSize(s);
+
+            QSize s2 = size();
+            s2.transpose();
+            titleRect.setSize(s2);
+
+            painter.translate(rect.left(), rect.top() + rect.width());
+            painter.rotate(-90);
+            painter.translate(-rect.left(), -rect.top());
+        }
+
+        contents.setTopLeft(titleRect.bottomLeft());
+        contents.setRight(titleRect.right());
+        contents.setBottom(rect.bottom()-y());
+
+        QRect rect = titleRect;
+
+
+        painter.drawPixmap(rect.topLeft(), leftPm.mask());
+        painter.fillRect(rect.left() + leftPm.width(), rect.top(),
+            rect.width() - leftPm.width() - rightPm.width(),
+            centerPm.height(), Qt::color1);
+        painter.drawPixmap(rect.topRight() - QPoint(rightPm.width() - 1, 0), rightPm.mask());
+
+        painter.fillRect(contents, Qt::color1);
+    }
+
+    dw->setMask(bitmap);
+}
+
 #include "colorswatch.moc"
