@@ -1,49 +1,47 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "colors.h"
 
-#ifndef QT_NO_OPENGL    
+#ifndef QT_NO_OPENGL
     #include <QGLWidget>
 #endif
 //#define QT_NO_OPENGL
@@ -73,7 +71,13 @@ int Colors::contentStartY = 22;
 int Colors::contentHeight = 510;
 
 // Properties:
-bool Colors::noOpenGl = false;
+bool Colors::openGlRendering = false;
+bool Colors::direct3dRendering = false;
+bool Colors::softwareRendering = false;
+bool Colors::openGlAwailable = true;
+bool Colors::direct3dAwailable = true;
+bool Colors::xRenderPresent = true;
+
 bool Colors::noTicker = false;
 bool Colors::noRescale = false;
 bool Colors::noAnimations = false;
@@ -87,13 +91,14 @@ bool Colors::showFps = false;
 bool Colors::noAdapt = false;
 bool Colors::noWindowMask = true;
 bool Colors::useButtonBalls = false;
-bool Colors::low = false;
 bool Colors::useEightBitPalette = false;
 bool Colors::noTimerUpdate = false;
 bool Colors::noTickerMorph = false;
 bool Colors::adapted = false;
 bool Colors::verbose = false;
-int Colors::fps = 100;
+bool Colors::pause = true;
+int Colors::fps = 60;
+int Colors::menuCount = 18;
 float Colors::animSpeed = 1.0;
 float Colors::animSpeedButtons = 1.0;
 float Colors::benchmarkFps = -1;
@@ -101,6 +106,7 @@ int Colors::tickerLetterCount = 80;
 float Colors::tickerMoveSpeed = 0.4f;
 float Colors::tickerMorphSpeed = 2.5f;
 QString Colors::tickerText = ".EROM ETAERC .SSEL EDOC";
+QString Colors::rootMenuName = "Qt Examples and Demos";
 
 QFont Colors::contentFont()
 {
@@ -136,7 +142,7 @@ QFont Colors::buttonFont()
 #else
     font.setPixelSize(11);
     font.setFamily("Verdana");
-#endif    
+#endif
     return font;
 }
 
@@ -152,7 +158,7 @@ QFont Colors::tickerFont()
     font.setPixelSize(10);
     font.setBold(true);
     font.setFamily("sans serif");
-#endif    
+#endif
     return font;
 }
 
@@ -188,24 +194,36 @@ void Colors::parseArgs(int argc, char *argv[])
     // others. Handle them now:
     for (int i=1; i<argc; i++){
         QString s(argv[i]);
-        if (s == "-no-adapt")
-             Colors::noAdapt = true;
-        else if (s == "-low")
-             Colors::low = true;
-        else if (s == "-verbose")
+        if (s == "-verbose")
             Colors::verbose = true;
     }
 
-    Colors::adaptAccordingToEnvironment();
+    Colors::detectSystemResources();
 
     // Handle the rest of the arguments. They may
     // override attributes already set:
     for (int i=1; i<argc; i++){
         QString s(argv[i]);
-        if (s == "-no-opengl")
-            Colors::noOpenGl = true;
-        else if (s == "-no-ticker")
+        if (s == "-opengl")
+            Colors::openGlRendering = true;
+        else if (s == "-direct3d")
+            Colors::direct3dRendering = true;
+        else if (s == "-software")
+            Colors::softwareRendering = true;
+        else if (s == "-no-opengl") // support old style
+            Colors::softwareRendering = true;
+        else if (s == "-no-ticker") // support old style
             Colors::noTicker = true;
+        else if (s.startsWith("-ticker"))
+            Colors::noTicker = !bool(parseFloat(s, "-ticker"));
+        else if (s == "-no-animations")
+            Colors::noAnimations = true; // support old style
+        else if (s.startsWith("-animations"))
+            Colors::noAnimations = !bool(parseFloat(s, "-animations"));
+        else if (s == "-no-adapt")
+            Colors::noAdapt = true;
+        else if (s == "-low")
+            Colors::setLowSettings();
         else if (s == "-no-rescale")
             Colors::noRescale = true;
         else if (s == "-use-pixmaps")
@@ -216,14 +234,16 @@ void Colors::parseArgs(int argc, char *argv[])
             Colors::showBoundingRect = true;
         else if (s == "-show-fps")
             Colors::showFps = true;
-        else if (s == "-no-animations")
-            Colors::noAnimations = true;
         else if (s == "-no-blending")
             Colors::noBlending = true;
         else if (s == "-no-sync")
             Colors::noScreenSync = true;
+        else if (s.startsWith("-menu"))
+            Colors::menuCount = int(parseFloat(s, "-menu"));
         else if (s.startsWith("-use-timer-update"))
             Colors::noTimerUpdate = !bool(parseFloat(s, "-use-timer-update"));
+        else if (s.startsWith("-pause"))
+            Colors::pause = bool(parseFloat(s, "-pause"));
         else if (s == "-no-ticker-morph")
             Colors::noTickerMorph = true;
         else if (s == "-use-window-mask")
@@ -232,6 +252,8 @@ void Colors::parseArgs(int argc, char *argv[])
             Colors::useLoop = true;
         else if (s == "-use-8bit")
             Colors::useEightBitPalette = true;
+        else if (s.startsWith("-8bit"))
+            Colors::useEightBitPalette = bool(parseFloat(s, "-8bit"));
         else if (s == "-use-balls")
             Colors::useButtonBalls = true;
         else if (s.startsWith("-ticker-letters"))
@@ -248,15 +270,38 @@ void Colors::parseArgs(int argc, char *argv[])
             Colors::fps = int(parseFloat(s, "-fps"));
         else if (s.startsWith("-h") || s.startsWith("-help")){
             QMessageBox::warning(0, "Arguments",
-                                 QString("Usage: qtdemo [-no-adapt] [-no-opengl] [-no-ticker] [-no-rescale] ")
-                                 + "[-no-animations] [-no-blending] [-no-sync] [-verbose] [-use-timer-update[0|1]] [-use-window-mask] [-fullscreen] "
-                                 + "[-use-pixmaps] [-show-fps] [-show-br] [-use-8bit] [-use-loop] [-use-balls] [-animation-speed<float>] [-fps<int>] "
+                                 QString("Usage: qtdemo [-verbose] [-no-adapt] [-opengl] [-direct3d] [-software] [-fullscreen] [-ticker[0|1]] ")
+                                 + "[-animations[0|1]] [-no-blending] [-no-sync] [-use-timer-update[0|1]] [-pause[0|1]]  "
+                                 + "[-use-window-mask] [-no-rescale] "
+                                 + "[-use-pixmaps] [-show-fps] [-show-br] [-8bit[0|1]] [-menu<int>] [-use-loop] [-use-balls] "
+                                 + "[-animation-speed<float>] [-fps<int>] "
                                  + "[-low] [-ticker-letters<int>] [-ticker-speed<float>] [-no-ticker-morph] "
                                  + "[-ticker-morph-speed<float>] [-ticker-text<string>]");
             exit(0);
-        }   
+        } else{
+            QMessageBox::warning(0, "QtDemo", QString("Unrecognized argument:\n") + s);
+            exit(0);
+        }
     }
 
+    Colors::postConfigure();
+}
+
+void Colors::setLowSettings()
+{
+    Colors::openGlRendering = false;
+    Colors::direct3dRendering = false;
+    Colors::softwareRendering = true;
+    Colors::noTicker = true;
+    Colors::noTimerUpdate = true;
+    Colors::fps = 30;
+    Colors::usePixmaps = true;
+    Colors::noAnimations = true;
+    Colors::noBlending = true;
+}
+
+void Colors::detectSystemResources()
+{
 #ifndef QT_NO_OPENGL
     if (QGLFormat::openGLVersionFlags() & QGLFormat::OpenGL_Version_2_0)
         Colors::glVersion = "2.0 or higher";
@@ -266,70 +311,83 @@ void Colors::parseArgs(int argc, char *argv[])
         Colors::glVersion = "1.4";
     else if (QGLFormat::openGLVersionFlags() & QGLFormat::OpenGL_Version_1_3)
         Colors::glVersion = "1.3 or lower";
+    if (Colors::verbose)
+        qDebug() << "- OpenGL version:" << Colors::glVersion;
 
-    if (!QGLFormat::hasOpenGL())
-#endif        
-        Colors::noOpenGl = true;
-}
-
-void Colors::adaptAccordingToEnvironment()
-{
-    if (Colors::noAdapt)
-        return;
-
-#if defined(Q_WS_X11)
-    // check if X render is present:
-    QPixmap tmp(1, 1);
-    if (!tmp.x11PictureHandle()){
-        Colors::low = true;
-        Colors::useEightBitPalette = true;
-        Colors::adapted = true;
-        if (Colors::verbose)
-            qDebug("- Adapt: X render not present.");
-    }
-#endif
-
-#ifndef QT_NO_OPENGL    
     QGLWidget glw;
-    if (Colors::low
-        || !QGLFormat::hasOpenGL()
+    if (!QGLFormat::hasOpenGL()
         || !glw.format().directRendering()
         || !(QGLFormat::openGLVersionFlags() & QGLFormat::OpenGL_Version_1_5)
         || glw.depth() < 24
     )
-#endif    
+#else
+    if (Colors::verbose)
+        qDebug() << "- OpenGL not supported by current build of Qt";
+#endif
     {
-        // Since we are not going to use OpenGL,
-        // turn off the most requiering stuff:
-        Colors::noOpenGl = true;
-        Colors::noTicker = true;
-	    Colors::fps = 50;
-        Colors::usePixmaps = true;
-        Colors::adapted = true;
+        Colors::openGlAwailable = false;
         if (Colors::verbose)
-            qDebug("- Adapt: not using OpenGL.");
+            qDebug("- OpenGL not recommended on this system");
     }
 
-    if (Colors::low){
-        Colors::noOpenGl = true;
-        Colors::noTicker = true;
-	    Colors::noTimerUpdate = true;
-	    Colors::fps = 30;
-        Colors::usePixmaps = true;
-        Colors::noAnimations = true;
-        Colors::noBlending = true;
-        Colors::low = true;
-        Colors::adapted = true;
+#if defined(Q_WS_WIN)
+    Colors::direct3dAwailable = false; // for now.
+#endif
+
+#if defined(Q_WS_X11)
+    // check if X render is present:
+    QPixmap tmp(1, 1);
+    if (!tmp.x11PictureHandle() && tmp.paintEngine()->type() == QPaintEngine::X11){
+        Colors::xRenderPresent = false;
         if (Colors::verbose)
-            qDebug("- Adapt: using setting 'low'.");
+            qDebug("- X render not present");
     }
 
+#endif
+
     QWidget w;
-    if (w.depth() < 16){
-        Colors::useEightBitPalette = true;
-        Colors::adapted = true;
-        if (Colors::verbose)
-            qDebug("- Adapt: color depth < 16. Using 8 bit palette.");
+    if (Colors::verbose)
+        qDebug() << "- Color depth: " << QString::number(w.depth());
+}
+
+void Colors::postConfigure()
+{
+    if (!Colors::noAdapt){
+        QWidget w;
+        if (w.depth() < 16){
+            Colors::useEightBitPalette = true;
+            Colors::adapted = true;
+            if (Colors::verbose)
+                qDebug() << "- Adapt: Color depth less than 16 bit. Using 8 bit palette";
+        }
+
+        if (!Colors::xRenderPresent){
+            Colors::setLowSettings();
+            Colors::adapted = true;
+            if (Colors::verbose)
+                qDebug() << "- Adapt: X renderer not present. Using low settings";
+        }
+    }
+
+#if !defined(Q_WS_WIN)
+    if (Colors::direct3dRendering){
+        Colors::direct3dRendering = false;
+            qDebug() << "- WARNING: Direct3D specified, but not supported on this platform";
+    }
+#endif
+
+    if (!Colors::openGlRendering && !Colors::direct3dRendering && !Colors::softwareRendering){
+        // The user has not decided rendering system. So we do it instead:
+#if defined(Q_WS_WIN)
+        if (Colors::direct3dAwailable)
+            Colors::direct3dRendering = true;
+        else
+#endif
+        if (Colors::openGlAwailable)
+            Colors::openGlRendering = true;
+        else
+            Colors::softwareRendering = true;
     }
 }
 
+
