@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -56,26 +54,39 @@ public:
     TextButton::BUTTONTYPE type;
     bool highlighted;
     bool pressed;
+    QSize logicalSize;
 
-    ButtonBackground(TextButton::BUTTONTYPE type, bool highlighted, bool pressed, QGraphicsScene *scene, QGraphicsItem *parent) : DemoItem(scene, parent)
+    ButtonBackground(TextButton::BUTTONTYPE type, bool highlighted, bool pressed, QSize logicalSize,
+        QGraphicsScene *scene, QGraphicsItem *parent) : DemoItem(scene, parent)
     {
         this->type = type;
         this->highlighted = highlighted;
         this->pressed = pressed;
+        this->logicalSize = logicalSize;
         useSharedImage(QString(__FILE__) + static_cast<int>(type) + highlighted + pressed);
     }
 
 protected:
     QImage *createImage(const QMatrix &matrix) const
     {
-        QRect scaledRect = matrix.mapRect(QRect(0, 0, BUTTON_WIDTH, BUTTON_HEIGHT));
+        if (type == TextButton::SIDEBAR || type == TextButton::PANEL)
+            return createRoundButtonBackground(matrix);
+        else
+            return createArrowBackground(matrix);
+    }
+
+    QImage *createRoundButtonBackground(const QMatrix &matrix) const
+    {
+        QRect scaledRect;
+        scaledRect = matrix.mapRect(QRect(0, 0, this->logicalSize.width(), this->logicalSize.height()));
+
         QImage *image = new QImage(scaledRect.width(), scaledRect.height(), QImage::Format_ARGB32_Premultiplied);
         image->fill(QColor(0, 0, 0, 0).rgba());
         QPainter painter(image);
         painter.setRenderHint(QPainter::SmoothPixmapTransform);
         painter.setRenderHint(QPainter::Antialiasing);
         painter.setPen(Qt::NoPen);
-        
+
         if (Colors::useEightBitPalette){
             painter.setPen(QColor(120, 120, 120));
             if (this->pressed)
@@ -88,7 +99,7 @@ protected:
         else {
             QLinearGradient outlinebrush(0, 0, 0, scaledRect.height());
             QLinearGradient brush(0, 0, 0, scaledRect.height());
-            
+
             brush.setSpread(QLinearGradient::PadSpread);
             QColor highlight(255, 255, 255, 70);
             QColor shadow(0, 0, 0, 70);
@@ -105,32 +116,123 @@ protected:
                outlinebrush.setColorAt(0.0f, shadow);
                outlinebrush.setColorAt(1.0f, highlight);
                brush.setColorAt(0.0f, sunken);
-               painter.setPen(Qt::NoPen);                    
+               painter.setPen(Qt::NoPen);
            } else {
                outlinebrush.setColorAt(1.0f, shadow);
                outlinebrush.setColorAt(0.0f, highlight);
-               brush.setColorAt(0.0f, normal1);                    
+               brush.setColorAt(0.0f, normal1);
                if (!this->highlighted)
                    brush.setColorAt(1.0f, normal2);
                painter.setPen(QPen(outlinebrush, 1));
            }
            painter.setBrush(brush);
         }
-        painter.drawRoundRect(0, 0, scaledRect.width(), scaledRect.height(), 10, 90);
+
+        if (this->type == TextButton::PANEL)
+            painter.drawRect(0, 0, scaledRect.width(), scaledRect.height());
+        else
+            painter.drawRoundedRect(0, 0, scaledRect.width(), scaledRect.height(), 10, 90, Qt::RelativeSize);
         return image;
     }
+
+    QImage *createArrowBackground(const QMatrix &matrix) const
+    {
+        QRect scaledRect;
+        scaledRect = matrix.mapRect(QRect(0, 0, this->logicalSize.width(), this->logicalSize.height()));
+
+        QImage *image = new QImage(scaledRect.width(), scaledRect.height(), QImage::Format_ARGB32_Premultiplied);
+        image->fill(QColor(0, 0, 0, 0).rgba());
+        QPainter painter(image);
+        painter.setRenderHint(QPainter::SmoothPixmapTransform);
+        painter.setRenderHint(QPainter::Antialiasing);
+        painter.setPen(Qt::NoPen);
+
+        if (Colors::useEightBitPalette){
+            painter.setPen(QColor(120, 120, 120));
+            if (this->pressed)
+                painter.setBrush(QColor(60, 60, 60));
+            else if (this->highlighted)
+                painter.setBrush(QColor(100, 100, 100));
+            else
+                painter.setBrush(QColor(80, 80, 80));
+        }
+        else {
+            QLinearGradient outlinebrush(0, 0, 0, scaledRect.height());
+            QLinearGradient brush(0, 0, 0, scaledRect.height());
+
+            brush.setSpread(QLinearGradient::PadSpread);
+            QColor highlight(255, 255, 255, 70);
+            QColor shadow(0, 0, 0, 70);
+            QColor sunken(220, 220, 220, 30);
+            QColor normal1 = QColor(200, 170, 160, 50);
+            QColor normal2 = QColor(50, 10, 0, 50);
+
+           if (pressed) {
+               outlinebrush.setColorAt(0.0f, shadow);
+               outlinebrush.setColorAt(1.0f, highlight);
+               brush.setColorAt(0.0f, sunken);
+               painter.setPen(Qt::NoPen);
+           } else {
+               outlinebrush.setColorAt(1.0f, shadow);
+               outlinebrush.setColorAt(0.0f, highlight);
+               brush.setColorAt(0.0f, normal1);
+               if (!this->highlighted)
+                   brush.setColorAt(1.0f, normal2);
+               painter.setPen(QPen(outlinebrush, 1));
+           }
+           painter.setBrush(brush);
+        }
+
+        painter.drawRect(0, 0, scaledRect.width(), scaledRect.height());
+
+        float xOff = scaledRect.width() / 2;
+        float yOff = scaledRect.height() / 2;
+        float sizex = 3.0f * matrix.m11();
+        float sizey = 1.5f * matrix.m22();
+        if (this->type == TextButton::UP)
+            sizey *= -1;
+        QPainterPath path;
+        path.moveTo(xOff, yOff + (5 * sizey));
+        path.lineTo(xOff - (4 * sizex), yOff - (3 * sizey));
+        path.lineTo(xOff + (4 * sizex), yOff - (3 * sizey));
+        path.lineTo(xOff, yOff + (5 * sizey));
+        painter.drawPath(path);
+
+        return image;
+    }
+
 };
 
-TextButton::TextButton(const QString &text, ALIGNMENT align, int userCode, QGraphicsScene *scene, QGraphicsItem *parent, BUTTONTYPE type)
+TextButton::TextButton(const QString &text, ALIGNMENT align, int userCode,
+    QGraphicsScene *scene, QGraphicsItem *parent, BUTTONTYPE type)
     : DemoItem(scene, parent)
 {
-    this->menuName = text;
+    this->menuString = text;
+    this->buttonLabel = text;
     this->alignment = align;
     this->buttonType = type;
     this->userCode = userCode;
+    this->bgOn = 0;
+    this->bgOff = 0;
+    this->bgHighlight = 0;
+    this->bgDisabled = 0;
+    this->state = OFF;
 
     this->setAcceptsHoverEvents(true);
     this->setCursor(Qt::PointingHandCursor);
+
+    // Calculate button size:
+    const int w = 180;
+    const int h = 19;
+    if (type == SIDEBAR || type == PANEL)
+        this->logicalSize = QSize(w, h);
+    else
+        this->logicalSize = QSize(int((w / 2.0f) - 5), int(h * 1.5f));
+}
+
+void TextButton::setMenuString(const QString &menu)
+{
+    this->menuString = menu;
 }
 
 void TextButton::prepare()
@@ -153,12 +255,15 @@ TextButton::~TextButton()
 
 QRectF TextButton::boundingRect() const
 {
-    return QRectF(0, 0, BUTTON_WIDTH, BUTTON_HEIGHT);
+    return QRectF(0, 0, this->logicalSize.width(), this->logicalSize.height());
 };
 
 void TextButton::setupHoverText()
 {
-    DemoTextItem *textItem = new DemoTextItem(this->menuName, Colors::buttonFont(), Colors::buttonText, -1, this->scene(), this);
+    if (this->buttonLabel.isEmpty())
+        return;
+
+    DemoTextItem *textItem = new DemoTextItem(this->buttonLabel, Colors::buttonFont(), Colors::buttonText, -1, this->scene(), this);
     textItem->setZValue(zValue() + 2);
     textItem->setPos(16, 0);
 }
@@ -168,10 +273,10 @@ void TextButton::setupScanItem()
     if (Colors::useButtonBalls){
         ScanItem *scanItem = new ScanItem(0, this);
         scanItem->setZValue(zValue() + 1);
-        
+
         this->scanAnim = new DemoItemAnimation(scanItem);
         this->scanAnim->timeline->setLoopCount(1);
-        
+
         float x = 1;
         float y = 1.5f;
         float stop = BUTTON_WIDTH - scanItem->boundingRect().width() - x;
@@ -192,80 +297,87 @@ void TextButton::setupScanItem()
     }
 }
 
-void TextButton::setupButtonBg()
+void TextButton::setState(STATE state)
 {
-    this->bgOff = new ButtonBackground(this->buttonType, false, false, this->scene(), this);
-    this->bgOn = new ButtonBackground(this->buttonType, true, false, this->scene(), this);
-    this->bgPressed = new ButtonBackground(this->buttonType, true, true, this->scene(), this);
-    this->bgOn->setRecursiveVisible(false);
-    this->bgPressed->setRecursiveVisible(false);    
-    this->bgOff->setRecursiveVisible(true);
+    this->state = state;
+    this->bgOn->setRecursiveVisible(state == ON);
+    this->bgOff->setRecursiveVisible(state == OFF);
+    this->bgHighlight->setRecursiveVisible(state == HIGHLIGHT);
+    this->bgDisabled->setRecursiveVisible(state == DISABLED);
+    this->setCursor(state == DISABLED ? Qt::ArrowCursor : Qt::PointingHandCursor);
+
 }
 
-void TextButton::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
+void TextButton::setupButtonBg()
 {
-    Q_UNUSED(event);
+    this->bgOn = new ButtonBackground(this->buttonType, true, true, this->logicalSize, this->scene(), this);
+    this->bgOff = new ButtonBackground(this->buttonType, false, false, this->logicalSize, this->scene(), this);
+    this->bgHighlight = new ButtonBackground(this->buttonType, true, false, this->logicalSize, this->scene(), this);
+    this->bgDisabled = new ButtonBackground(this->buttonType, true, true, this->logicalSize, this->scene(), this);
+    this->setState(OFF);
+}
 
-    if (this->locked)
+void TextButton::hoverEnterEvent(QGraphicsSceneHoverEvent *)
+{
+    if (this->locked || this->state == DISABLED)
         return;
 
-    if (Colors::noAnimations && Colors::useButtonBalls){
-        // wait a bit in the beginning
-        // to enhance the effect. Have to this here
-        // so that the adaption can be dynamic
-        this->scanAnim->setDuration(1000);
-        this->scanAnim->setPosAt(0.2, this->scanAnim->posAt(0));
-    }
+    if (this->state == OFF){
+        this->setState(HIGHLIGHT);
 
-    if (MenuManager::instance()->window->fpsMedian > 10
-        || Colors::noAdapt
-        || Colors::noTimerUpdate){
-        if (Colors::useButtonBalls)
-            this->scanAnim->play(true, true);
+        if (Colors::noAnimations && Colors::useButtonBalls){
+            // wait a bit in the beginning
+            // to enhance the effect. Have to this here
+            // so that the adaption can be dynamic
+            this->scanAnim->setDuration(1000);
+            this->scanAnim->setPosAt(0.2, this->scanAnim->posAt(0));
+        }
+
+        if (MenuManager::instance()->window->fpsMedian > 10
+            || Colors::noAdapt
+            || Colors::noTimerUpdate){
+            if (Colors::useButtonBalls)
+                this->scanAnim->play(true, true);
+        }
     }
-   this->bgOn->setRecursiveVisible(true);
-   this->bgOff->setRecursiveVisible(false);
-   this->bgPressed->setRecursiveVisible(false);
 }
 
 void TextButton::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
     Q_UNUSED(event);
+    if (this->state == DISABLED)
+        return;
+
+    this->setState(OFF);
 
     if (Colors::noAnimations && Colors::useButtonBalls)
         this->scanAnim->stop();
-    this->bgOn->setRecursiveVisible(false);
-    this->bgOff->setRecursiveVisible(true);
-    this->bgPressed->setRecursiveVisible(false);
 }
 
-void TextButton::mousePressEvent(QGraphicsSceneMouseEvent *event)
+void TextButton::mousePressEvent(QGraphicsSceneMouseEvent *)
 {
-    Q_UNUSED(event);
+    if (this->state == DISABLED)
+        return;
 
-    this->bgPressed->setRecursiveVisible(true);
-    this->bgOn->setRecursiveVisible(false);
-    this->bgOff->setRecursiveVisible(false);
+    if (this->state == HIGHLIGHT || this->state == OFF)
+        this->setState(ON);
 }
 
 void TextButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-    Q_UNUSED(event);
-
-    this->bgPressed->setRecursiveVisible(false);
-    this->bgOn->setRecursiveVisible(false);
-    this->bgOff->setRecursiveVisible(true);
-
-    if (!this->locked && this->boundingRect().contains(event->pos())){
-        MenuManager::instance()->itemSelected(this->userCode, this->menuName);
+    if (this->state == ON){
+        this->setState(OFF);
+        if (!this->locked && this->boundingRect().contains(event->pos())){
+            MenuManager::instance()->itemSelected(this->userCode, this->menuString);
+        }
     }
 }
 
 void TextButton::animationStarted(int)
 {
-    this->bgOn->setRecursiveVisible(false);
-    this->bgPressed->setRecursiveVisible(false);    
-    this->bgOff->setRecursiveVisible(true);
+    if (this->state == DISABLED)
+        return;
+    this->setState(OFF);
 }
 
 
