@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -46,6 +51,8 @@
 #include <QTextBrowser>
 #include <QBoxLayout>
 
+#include <private/qpixmapdata_p.h>
+
 extern QPixmap cached(const QString &img);
 
 ArthurFrame::ArthurFrame(QWidget *parent)
@@ -65,12 +72,12 @@ ArthurFrame::ArthurFrame(QWidget *parent)
     m_document = 0;
     m_show_doc = false;
 
-    m_tile = QPixmap(100, 100);
+    m_tile = QPixmap(128, 128);
     m_tile.fill(Qt::white);
     QPainter pt(&m_tile);
-    QColor color(240, 240, 240);
-    pt.fillRect(0, 0, 50, 50, color);
-    pt.fillRect(50, 50, 50, 50, color);
+    QColor color(230, 230, 230);
+    pt.fillRect(0, 0, 64, 64, color);
+    pt.fillRect(64, 64, 64, 64, color);
     pt.end();
 
 //     QPalette pal = palette();
@@ -79,7 +86,7 @@ ArthurFrame::ArthurFrame(QWidget *parent)
 
 #ifdef Q_WS_X11
     QPixmap xRenderPixmap(1, 1);
-    m_prefer_image = !xRenderPixmap.x11PictureHandle();
+    m_prefer_image = xRenderPixmap.pixmapData()->classId() == QPixmapData::X11Class && !xRenderPixmap.x11PictureHandle();
 #endif
 }
 
@@ -101,23 +108,31 @@ void ArthurFrame::enableOpenGL(bool use_opengl)
     } else {
         glw->hide();
     }
+
+    update();
 }
 #endif
 
 void ArthurFrame::paintEvent(QPaintEvent *e)
 {
+#ifdef Q_WS_QWS
+    static QPixmap *static_image = 0;
+#else
     static QImage *static_image = 0;
+#endif
     QPainter painter;
     if (preferImage()
 #ifdef QT_OPENGL_SUPPORT
         && !m_use_opengl
 #endif
         ) {
-        if (!static_image) {
-            static_image = new QImage(size(), QImage::Format_RGB32);
-        } else if (static_image->size() != size()) {
+        if (!static_image || static_image->size() != size()) {
             delete static_image;
+#ifdef Q_WS_QWS
+            static_image = new QPixmap(size());
+#else
             static_image = new QImage(size(), QImage::Format_RGB32);
+#endif
         }
         painter.begin(static_image);
 
@@ -148,11 +163,11 @@ void ArthurFrame::paintEvent(QPaintEvent *e)
     QPainterPath clipPath;
 
     QRect r = rect();
-    double left = r.x() + 1;
-    double top = r.y() + 1;
-    double right = r.right();
-    double bottom = r.bottom();
-    double radius2 = 8 * 2;
+    qreal left = r.x() + 1;
+    qreal top = r.y() + 1;
+    qreal right = r.right();
+    qreal bottom = r.bottom();
+    qreal radius2 = 8 * 2;
 
     clipPath.moveTo(right - radius2, top);
     clipPath.arcTo(right - radius2, top, radius2, radius2, 90, -90);
@@ -189,7 +204,11 @@ void ArthurFrame::paintEvent(QPaintEvent *e)
         ) {
         painter.end();
         painter.begin(this);
+#ifdef Q_WS_QWS
+        painter.drawPixmap(e->rect(), *static_image, e->rect());
+#else
         painter.drawImage(e->rect(), *static_image, e->rect());
+#endif
     }
 
 #ifdef QT_OPENGL_SUPPORT
