@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -55,6 +53,7 @@
 #include "multipagewidgetplugin.h"
 #include "multipagewidgetextensionfactory.h"
 
+//! [0]
 MultiPageWidgetPlugin::MultiPageWidgetPlugin(QObject *parent)
     :QObject(parent)
 {
@@ -91,11 +90,13 @@ QIcon MultiPageWidgetPlugin::icon() const
     return QIcon();
 }
 
+//! [0] //! [1]
 bool MultiPageWidgetPlugin::isContainer() const
 {
     return true;
 }
 
+//! [1] //! [2]
 QWidget *MultiPageWidgetPlugin::createWidget(QWidget *parent)
 {
     MultiPageWidget *widget = new MultiPageWidget(parent);
@@ -106,17 +107,23 @@ QWidget *MultiPageWidgetPlugin::createWidget(QWidget *parent)
     return widget;
 }
 
+//! [2] //! [3]
 bool MultiPageWidgetPlugin::isInitialized() const
 {
     return initialized;
 }
+//! [3]
 
+//! [4]
 void MultiPageWidgetPlugin::initialize(QDesignerFormEditorInterface *formEditor)
 {
     if (initialized)
         return;
+//! [4]
 
+//! [5]
     QExtensionManager *manager = formEditor->extensionManager();
+//! [5] //! [6]
     QExtensionFactory *factory = new MultiPageWidgetExtensionFactory(manager);
 
     Q_ASSERT(manager != 0);
@@ -124,38 +131,57 @@ void MultiPageWidgetPlugin::initialize(QDesignerFormEditorInterface *formEditor)
 
     initialized = true;
 }
+//! [6]
 
+//! [7]
 QString MultiPageWidgetPlugin::domXml() const
 {
     return QLatin1String("\
+<ui language=\"c++\">\
     <widget class=\"MultiPageWidget\" name=\"multipagewidget\">\
         <widget class=\"QWidget\" name=\"page\" />\
     </widget>\
-    ");
+    <customwidgets>\
+        <customwidget>\
+            <class>MultiPageWidget</class>\
+            <extends>QWidget</extends>\
+            <addpagemethod>addPage</addpagemethod>\
+        </customwidget>\
+    </customwidgets>\
+</ui>");
 }
+//! [7]
 
+//! [8]
 void MultiPageWidgetPlugin::currentIndexChanged(int index)
 {
     Q_UNUSED(index);
     MultiPageWidget *widget = qobject_cast<MultiPageWidget*>(sender());
+//! [8] //! [9]
     if (widget) {
         QDesignerFormWindowInterface *form = QDesignerFormWindowInterface::findFormWindow(widget);
         if (form)
             form->emitSelectionChanged();
     }
 }
+//! [9]
 
+//! [10]
 void MultiPageWidgetPlugin::pageTitleChanged(const QString &title)
 {
     Q_UNUSED(title);
     MultiPageWidget *widget = qobject_cast<MultiPageWidget*>(sender());
+//! [10] //! [11]
     if (widget) {
         QWidget *page = widget->widget(widget->currentIndex());
         QDesignerFormWindowInterface *form;
         form = QDesignerFormWindowInterface::findFormWindow(widget);
+//! [11]
         if (form) {
+//! [12]
             QDesignerFormEditorInterface *editor = form->core();
             QExtensionManager *manager = editor->extensionManager();
+//! [12] //! [13]
             QDesignerPropertySheetExtension *sheet;
             sheet = qt_extension<QDesignerPropertySheetExtension*>(manager, page);
             const int propertyIndex = sheet->indexOf(QLatin1String("windowTitle"));
@@ -164,4 +190,8 @@ void MultiPageWidgetPlugin::pageTitleChanged(const QString &title)
     }
 }
 
+//! [13]
+
+//! [14]
 Q_EXPORT_PLUGIN2(containerextension, MultiPageWidgetPlugin)
+//! [14]
