@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -45,6 +43,7 @@
 
 #include "screenshot.h"
 
+//! [0]
 Screenshot::Screenshot()
 {
     screenshotLabel = new QLabel;
@@ -68,7 +67,9 @@ Screenshot::Screenshot()
     setWindowTitle(tr("Screenshot"));
     resize(300, 200);
 }
+//! [0]
 
+//! [1]
 void Screenshot::resizeEvent(QResizeEvent * /* event */)
 {
     QSize scaledSize = originalPixmap.size();
@@ -77,7 +78,9 @@ void Screenshot::resizeEvent(QResizeEvent * /* event */)
             || scaledSize != screenshotLabel->pixmap()->size())
         updateScreenshotLabel();
 }
+//! [1]
 
+//! [2]
 void Screenshot::newScreenshot()
 {
     if (hideThisWindowCheckBox->isChecked())
@@ -86,7 +89,9 @@ void Screenshot::newScreenshot()
 
     QTimer::singleShot(delaySpinBox->value() * 1000, this, SLOT(shootScreen()));
 }
+//! [2]
 
+//! [3]
 void Screenshot::saveScreenshot()
 {
     QString format = "png";
@@ -100,11 +105,17 @@ void Screenshot::saveScreenshot()
     if (!fileName.isEmpty())
         originalPixmap.save(fileName, format.toAscii());
 }
+//! [3]
 
+//! [4]
 void Screenshot::shootScreen()
 {
     if (delaySpinBox->value() != 0)
         qApp->beep();
+//! [4]
+    originalPixmap = QPixmap(); // clear image for low memory situations
+                                // on embedded devices.
+//! [5]
     originalPixmap = QPixmap::grabWindow(QApplication::desktop()->winId());
     updateScreenshotLabel();
 
@@ -112,15 +123,21 @@ void Screenshot::shootScreen()
     if (hideThisWindowCheckBox->isChecked())
         show();
 }
+//! [5]
 
+//! [6]
 void Screenshot::updateCheckBox()
 {
-    if (delaySpinBox->value() == 0)
+    if (delaySpinBox->value() == 0) {
         hideThisWindowCheckBox->setDisabled(true);
+        hideThisWindowCheckBox->setChecked(false);
+    }
     else
         hideThisWindowCheckBox->setDisabled(false);
 }
+//! [6]
 
+//! [7]
 void Screenshot::createOptionsGroupBox()
 {
     optionsGroupBox = new QGroupBox(tr("Options"));
@@ -140,7 +157,9 @@ void Screenshot::createOptionsGroupBox()
     optionsGroupBoxLayout->addWidget(hideThisWindowCheckBox, 1, 0, 1, 2);
     optionsGroupBox->setLayout(optionsGroupBoxLayout);
 }
+//! [7]
 
+//! [8]
 void Screenshot::createButtonsLayout()
 {
     newScreenshotButton = createButton(tr("New Screenshot"),
@@ -157,7 +176,9 @@ void Screenshot::createButtonsLayout()
     buttonsLayout->addWidget(saveScreenshotButton);
     buttonsLayout->addWidget(quitScreenshotButton);
 }
+//! [8]
 
+//! [9]
 QPushButton *Screenshot::createButton(const QString &text, QWidget *receiver,
                                       const char *member)
 {
@@ -165,10 +186,13 @@ QPushButton *Screenshot::createButton(const QString &text, QWidget *receiver,
     button->connect(button, SIGNAL(clicked()), receiver, member);
     return button;
 }
+//! [9]
 
+//! [10]
 void Screenshot::updateScreenshotLabel()
 {
     screenshotLabel->setPixmap(originalPixmap.scaled(screenshotLabel->size(),
                                                      Qt::KeepAspectRatio,
                                                      Qt::SmoothTransformation));
 }
+//! [10]
