@@ -1,47 +1,46 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include <QtGui>
+#include <QLabel>
 
 #include "mainwindow.h"
 #include "diagramitem.h"
@@ -50,6 +49,7 @@
 
 const int InsertTextButton = 10;
 
+//! [0]
 MainWindow::MainWindow()
 {
     createActions();
@@ -77,7 +77,9 @@ MainWindow::MainWindow()
     setCentralWidget(widget);
     setWindowTitle(tr("Diagramscene"));
 }
+//! [0]
 
+//! [1]
 void MainWindow::backgroundButtonGroupClicked(QAbstractButton *button)
 {
     QList<QAbstractButton *> buttons = backgroundButtonGroup->buttons();
@@ -98,7 +100,9 @@ void MainWindow::backgroundButtonGroupClicked(QAbstractButton *button)
     scene->update();
     view->update();
 }
+//! [1]
 
+//! [2]
 void MainWindow::buttonGroupClicked(int id)
 {
     QList<QAbstractButton *> buttons = buttonGroup->buttons();
@@ -113,7 +117,9 @@ void MainWindow::buttonGroupClicked(int id)
         scene->setMode(DiagramScene::InsertItem);
     }
 }
+//! [2]
 
+//! [3]
 void MainWindow::deleteItem()
 {
     foreach (QGraphicsItem *item, scene->selectedItems()) {
@@ -123,12 +129,16 @@ void MainWindow::deleteItem()
         scene->removeItem(item);
     }
 }
+//! [3]
 
+//! [4]
 void MainWindow::pointerGroupClicked(int)
 {
     scene->setMode(DiagramScene::Mode(pointerTypeGroup->checkedId()));
 }
+//! [4]
 
+//! [5]
 void MainWindow::bringToFront()
 {
     if (scene->selectedItems().isEmpty())
@@ -145,7 +155,9 @@ void MainWindow::bringToFront()
     }
     selectedItem->setZValue(zValue);
 }
+//! [5]
 
+//! [6]
 void MainWindow::sendToBack()
 {
     if (scene->selectedItems().isEmpty())
@@ -162,29 +174,40 @@ void MainWindow::sendToBack()
     }
     selectedItem->setZValue(zValue);
 }
+//! [6]
 
+//! [7]
 void MainWindow::itemInserted(DiagramItem *item)
 {
+    pointerTypeGroup->button(int(DiagramScene::MoveItem))->setChecked(true);
     scene->setMode(DiagramScene::Mode(pointerTypeGroup->checkedId()));
     buttonGroup->button(int(item->diagramType()))->setChecked(false);
 }
+//! [7]
 
+//! [8]
 void MainWindow::textInserted(QGraphicsTextItem *)
 {
     buttonGroup->button(InsertTextButton)->setChecked(false);
     scene->setMode(DiagramScene::Mode(pointerTypeGroup->checkedId()));
 }
+//! [8]
 
+//! [9]
 void MainWindow::currentFontChanged(const QFont &)
 {
     handleFontChange();
 }
+//! [9]
 
+//! [10]
 void MainWindow::fontSizeChanged(const QString &)
 {
     handleFontChange();
 }
+//! [10]
 
+//! [11]
 void MainWindow::sceneScaleChanged(const QString &scale)
 {
     double newScale = scale.left(scale.indexOf(tr("%"))).toDouble() / 100.0;
@@ -193,7 +216,9 @@ void MainWindow::sceneScaleChanged(const QString &scale)
     view->translate(oldMatrix.dx(), oldMatrix.dy());
     view->scale(newScale, newScale);
 }
+//! [11]
 
+//! [12]
 void MainWindow::textColorChanged()
 {
     textAction = qobject_cast<QAction *>(sender());
@@ -202,7 +227,9 @@ void MainWindow::textColorChanged()
                 qVariantValue<QColor>(textAction->data())));
     textButtonTriggered();
 }
+//! [12]
 
+//! [13]
 void MainWindow::itemColorChanged()
 {
     fillAction = qobject_cast<QAction *>(sender());
@@ -211,7 +238,9 @@ void MainWindow::itemColorChanged()
                  qVariantValue<QColor>(fillAction->data())));
     fillButtonTriggered();
 }
+//! [13]
 
+//! [14]
 void MainWindow::lineColorChanged()
 {
     lineAction = qobject_cast<QAction *>(sender());
@@ -220,22 +249,30 @@ void MainWindow::lineColorChanged()
                  qVariantValue<QColor>(lineAction->data())));
     lineButtonTriggered();
 }
+//! [14]
 
+//! [15]
 void MainWindow::textButtonTriggered()
 {
     scene->setTextColor(qVariantValue<QColor>(textAction->data()));
 }
+//! [15]
 
+//! [16]
 void MainWindow::fillButtonTriggered()
 {
     scene->setItemColor(qVariantValue<QColor>(fillAction->data()));
 }
+//! [16]
 
+//! [17]
 void MainWindow::lineButtonTriggered()
 {
     scene->setLineColor(qVariantValue<QColor>(lineAction->data()));
 }
+//! [17]
 
+//! [18]
 void MainWindow::handleFontChange()
 {
     QFont font = fontCombo->currentFont();
@@ -246,7 +283,9 @@ void MainWindow::handleFontChange()
 
     scene->setFont(font);
 }
+//! [18]
 
+//! [19]
 void MainWindow::itemSelected(QGraphicsItem *item)
 {
     DiagramTextItem *textItem =
@@ -260,14 +299,18 @@ void MainWindow::itemSelected(QGraphicsItem *item)
     italicAction->setChecked(font.italic());
     underlineAction->setChecked(font.underline());
 }
+//! [19]
 
+//! [20]
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About Diagram Scene"),
                        tr("The <b>Diagram Scene</b> example shows "
                           "use of the graphics framework."));
 }
+//! [20]
 
+//! [21]
 void MainWindow::createToolBox()
 {
     buttonGroup = new QButtonGroup;
@@ -277,10 +320,11 @@ void MainWindow::createToolBox()
     QGridLayout *layout = new QGridLayout;
     layout->addWidget(createCellWidget(tr("Conditional"),
                                DiagramItem::Conditional), 0, 0);
-    layout->addWidget(createCellWidget(tr("Proccess"),
+    layout->addWidget(createCellWidget(tr("Process"),
                       DiagramItem::Step),0, 1);
     layout->addWidget(createCellWidget(tr("Input/Output"),
                       DiagramItem::Io), 1, 0);
+//! [21]
 
     QToolButton *textButton = new QToolButton;
     textButton->setCheckable(true);
@@ -322,13 +366,16 @@ void MainWindow::createToolBox()
     backgroundWidget->setLayout(backgroundLayout);
 
 
+//! [22]
     toolBox = new QToolBox;
     toolBox->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Ignored));
     toolBox->setMinimumWidth(itemWidget->sizeHint().width());
     toolBox->addItem(itemWidget, tr("Basic Flowchart Shapes"));
     toolBox->addItem(backgroundWidget, tr("Backgrounds"));
 }
+//! [22]
 
+//! [23]
 void MainWindow::createActions()
 {
     toFrontAction = new QAction(QIcon(":/images/bringtofront.png"),
@@ -337,6 +384,7 @@ void MainWindow::createActions()
     toFrontAction->setStatusTip(tr("Bring item to front"));
     connect(toFrontAction, SIGNAL(triggered()),
             this, SLOT(bringToFront()));
+//! [23]
 
     sendBackAction = new QAction(QIcon(":/images/sendtoback.png"),
                                  tr("Send to &Back"), this);
@@ -385,6 +433,7 @@ void MainWindow::createActions()
             this, SLOT(about()));
 }
 
+//! [24]
 void MainWindow::createMenus()
 {
     fileMenu = menuBar()->addMenu(tr("&File"));
@@ -399,9 +448,12 @@ void MainWindow::createMenus()
     aboutMenu = menuBar()->addMenu(tr("&Help"));
     aboutMenu->addAction(aboutAction);
 }
+//! [24]
 
+//! [25]
 void MainWindow::createToolbars()
 {
+//! [25]
     editToolBar = addToolBar(tr("Edit"));
     editToolBar->addAction(deleteAction);
     editToolBar->addAction(toFrontAction);
@@ -432,6 +484,7 @@ void MainWindow::createToolbars()
     connect(fontColorToolButton, SIGNAL(clicked()),
             this, SLOT(textButtonTriggered()));
 
+//! [26]
     fillColorToolButton = new QToolButton;
     fillColorToolButton->setPopupMode(QToolButton::MenuButtonPopup);
     fillColorToolButton->setMenu(createColorMenu(SLOT(itemColorChanged()),
@@ -441,6 +494,7 @@ void MainWindow::createToolbars()
     ":/images/floodfill.png", Qt::white));
     connect(fillColorToolButton, SIGNAL(clicked()),
             this, SLOT(fillButtonTriggered()));
+//! [26]
 
     lineColorToolButton = new QToolButton;
     lineColorToolButton->setPopupMode(QToolButton::MenuButtonPopup);
@@ -491,8 +545,11 @@ void MainWindow::createToolbars()
     pointerToolbar->addWidget(pointerButton);
     pointerToolbar->addWidget(linePointerButton);
     pointerToolbar->addWidget(sceneScaleCombo);
+//! [27]
 }
+//! [27]
 
+//! [28]
 QWidget *MainWindow::createBackgroundCellWidget(const QString &text,
                         const QString &image)
 {
@@ -512,7 +569,9 @@ QWidget *MainWindow::createBackgroundCellWidget(const QString &text,
 
     return widget;
 }
+//! [28]
 
+//! [29]
 QWidget *MainWindow::createCellWidget(const QString &text,
                       DiagramItem::DiagramType type)
 {
@@ -535,7 +594,9 @@ QWidget *MainWindow::createCellWidget(const QString &text,
 
     return widget;
 }
+//! [29]
 
+//! [30]
 QMenu *MainWindow::createColorMenu(const char *slot, QColor defaultColor)
 {
     QList<QColor> colors;
@@ -558,7 +619,9 @@ QMenu *MainWindow::createColorMenu(const char *slot, QColor defaultColor)
     }
     return colorMenu;
 }
+//! [30]
 
+//! [31]
 QIcon MainWindow::createColorToolButtonIcon(const QString &imageFile,
                         QColor color)
 {
@@ -573,7 +636,9 @@ QIcon MainWindow::createColorToolButtonIcon(const QString &imageFile,
 
     return QIcon(pixmap);
 }
+//! [31]
 
+//! [32]
 QIcon MainWindow::createColorIcon(QColor color)
 {
     QPixmap pixmap(20, 20);
@@ -583,3 +648,4 @@ QIcon MainWindow::createColorIcon(QColor color)
 
     return QIcon(pixmap);
 }
+//! [32]
