@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -121,8 +119,10 @@ KAsteroidsView::KAsteroidsView( QWidget *parent, const char *name )
     view.setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     view.setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     view.setCacheMode(QGraphicsView::CacheBackground);
-    view.setViewportUpdateMode(QGraphicsView::SmartViewportUpdate);
-    view.setOptimizationFlag(QGraphicsView::DontClipPainter);
+    view.setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
+    view.setOptimizationFlags(QGraphicsView::DontClipPainter
+                              | QGraphicsView::DontSavePainterState
+                              | QGraphicsView::DontAdjustForAntialiasing);
     view.viewport()->setFocusProxy( this );
     rocks.setAutoDelete( TRUE );
     missiles.setAutoDelete( TRUE );
@@ -136,6 +136,7 @@ KAsteroidsView::KAsteroidsView( QWidget *parent, const char *name )
     textSprite = new QGraphicsTextItem( 0, &field );
     QFont font( "helvetica", 18 );
     textSprite->setFont( font );
+    textSprite->setCacheMode(QGraphicsItem::DeviceCoordinateCache);
 
     shield = 0;
     shieldOn = FALSE;
@@ -624,17 +625,17 @@ void KAsteroidsView::processMissiles()
 
 	wrapSprite( missile );
 
-	QList<QGraphicsItem *> hits = missile->collidingItems();
+	QList<QGraphicsItem *> hits = missile->collidingItems(Qt::IntersectsItemBoundingRect);
 	QList<QGraphicsItem *>::Iterator hit;
 	for ( hit = hits.begin(); hit != hits.end(); ++hit )
 	{
 	    if ( (*hit)->type() >= ID_ROCK_LARGE &&
-		 (*hit)->type() <= ID_ROCK_SMALL )
+		 (*hit)->type() <= ID_ROCK_SMALL && (*hit)->collidesWithItem(missile) )
 	    {
-		shotsHit++;
-		rockHit( static_cast<AnimatedPixmapItem *>(*hit) );
-		missiles.removeRef( missile );
-		break;
+                shotsHit++;
+                rockHit( static_cast<AnimatedPixmapItem *>(*hit) );
+                missiles.removeRef( missile );
+                break;
 	    }
 	}
     }
@@ -657,12 +658,12 @@ void KAsteroidsView::processShip()
 		shield->setFrame( (shield->frame()+1) % shield->frameCount() );
 	    shield->setPos( ship->x() - 9, ship->y() - 9 );
 
-	    QList<QGraphicsItem *> hits = shield->collidingItems();
+	    QList<QGraphicsItem *> hits = shield->collidingItems(Qt::IntersectsItemBoundingRect);
 	    QList<QGraphicsItem *>::Iterator it;
 	    for ( it = hits.begin(); it != hits.end(); ++it )
 	    {
 		if ( (*it)->type() >= ID_ROCK_LARGE &&
-		     (*it)->type() <= ID_ROCK_SMALL )
+		     (*it)->type() <= ID_ROCK_SMALL && (*it)->collidesWithItem(shield) )
 		{
 		    int factor;
 		    switch ( (*it)->type() )
@@ -695,12 +696,12 @@ void KAsteroidsView::processShip()
 	if ( !shieldOn )
 	{
 	    shield->hide();
-	    QList<QGraphicsItem *> hits = ship->collidingItems();
+	    QList<QGraphicsItem *> hits = ship->collidingItems(Qt::IntersectsItemBoundingRect);
 	    QList<QGraphicsItem *>::Iterator it;
 	    for ( it = hits.begin(); it != hits.end(); ++it )
 	    {
 		if ( (*it)->type() >= ID_ROCK_LARGE &&
-		     (*it)->type() <= ID_ROCK_SMALL )
+		     (*it)->type() <= ID_ROCK_SMALL && (*it)->collidesWithItem(ship))
 		{
 		    KBit *bit;
 		    for ( int i = 0; i < 12; i++ )
@@ -954,11 +955,11 @@ void KAsteroidsView::showEvent( QShowEvent *e )
     static bool wasThere = FALSE;
 
     if ( !wasThere ) {
-	wasThere = TRUE;
-	QMessageBox::information( this, tr("QCanvas demo"),
-				  tr("This game has been implemented using the QCanvas class.\n"
-				     "The QCanvas class is not part of the Professional Edition. Please \n"
-				     "contact Trolltech if you want to upgrade to the Enterprise Edition.") );
+        wasThere = TRUE;
+        QMessageBox::information( this, tr("QGraphicsView demo"),
+                                        tr("This game has been implemented using the QGraphicsView class.\n"
+                                           "The QGraphicsView class is not part of the Light Platform Edition. Please \n"
+                                           "contact Nokia if you want to upgrade to the Full Platform Edition.") );
     }
 #endif
 
