@@ -1,50 +1,51 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
+//! [0]
 #include <QtGui>
 
 #include "mainwindow.h"
+//! [0]
 
+//! [1]
 MainWindow::MainWindow()
 {
     textEdit = new QTextEdit;
@@ -59,8 +60,11 @@ MainWindow::MainWindow()
     setWindowTitle(tr("Dock Widgets"));
 
     newLetter();
+    setUnifiedTitleAndToolBarOnMac(true);
 }
+//! [1]
 
+//! [2]
 void MainWindow::newLetter()
 {
     textEdit->clear();
@@ -106,9 +110,12 @@ void MainWindow::newLetter()
     cursor.insertBlock();
     cursor.insertText("ADDRESS", italicFormat);
 }
+//! [2]
 
+//! [3]
 void MainWindow::print()
 {
+#ifndef QT_NO_PRINTDIALOG
     QTextDocument *document = textEdit->document();
     QPrinter printer;
 
@@ -119,8 +126,11 @@ void MainWindow::print()
     document->print(&printer);
 
     statusBar()->showMessage(tr("Ready"), 2000);
+#endif
 }
+//! [3]
 
+//! [4]
 void MainWindow::save()
 {
     QString fileName = QFileDialog::getSaveFileName(this,
@@ -144,13 +154,17 @@ void MainWindow::save()
 
     statusBar()->showMessage(tr("Saved '%1'").arg(fileName), 2000);
 }
+//! [4]
 
+//! [5]
 void MainWindow::undo()
 {
     QTextDocument *document = textEdit->document();
     document->undo();
 }
+//! [5]
 
+//! [6]
 void MainWindow::insertCustomer(const QString &customer)
 {
     if (customer.isEmpty())
@@ -174,7 +188,9 @@ void MainWindow::insertCustomer(const QString &customer)
             oldcursor.endEditBlock();
     }
 }
+//! [6]
 
+//! [7]
 void MainWindow::addParagraph(const QString &paragraph)
 {
     if (paragraph.isEmpty())
@@ -191,6 +207,7 @@ void MainWindow::addParagraph(const QString &paragraph)
     cursor.endEditBlock();
 
 }
+//! [7]
 
 void MainWindow::about()
 {
@@ -205,22 +222,22 @@ void MainWindow::createActions()
 {
     newLetterAct = new QAction(QIcon(":/images/new.png"), tr("&New Letter"),
                                this);
-    newLetterAct->setShortcut(tr("Ctrl+N"));
+    newLetterAct->setShortcuts(QKeySequence::New);
     newLetterAct->setStatusTip(tr("Create a new form letter"));
     connect(newLetterAct, SIGNAL(triggered()), this, SLOT(newLetter()));
 
     saveAct = new QAction(QIcon(":/images/save.png"), tr("&Save..."), this);
-    saveAct->setShortcut(tr("Ctrl+S"));
+    saveAct->setShortcuts(QKeySequence::Save);
     saveAct->setStatusTip(tr("Save the current form letter"));
     connect(saveAct, SIGNAL(triggered()), this, SLOT(save()));
 
     printAct = new QAction(QIcon(":/images/print.png"), tr("&Print..."), this);
-    printAct->setShortcut(tr("Ctrl+P"));
+    printAct->setShortcuts(QKeySequence::Print);
     printAct->setStatusTip(tr("Print the current form letter"));
     connect(printAct, SIGNAL(triggered()), this, SLOT(print()));
 
     undoAct = new QAction(QIcon(":/images/undo.png"), tr("&Undo"), this);
-    undoAct->setShortcut(tr("Ctrl+Z"));
+    undoAct->setShortcuts(QKeySequence::Undo);
     undoAct->setStatusTip(tr("Undo the last editing action"));
     connect(undoAct, SIGNAL(triggered()), this, SLOT(undo()));
 
@@ -270,11 +287,14 @@ void MainWindow::createToolBars()
     editToolBar->addAction(undoAct);
 }
 
+//! [8]
 void MainWindow::createStatusBar()
 {
     statusBar()->showMessage(tr("Ready"));
 }
+//! [8]
 
+//! [9]
 void MainWindow::createDockWindows()
 {
     QDockWidget *dock = new QDockWidget(tr("Customers"), this);
@@ -320,3 +340,4 @@ void MainWindow::createDockWindows()
     connect(paragraphsList, SIGNAL(currentTextChanged(const QString &)),
             this, SLOT(addParagraph(const QString &)));
 }
+//! [9]
