@@ -1,37 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
-** Contact: Qt Software Information (qt-info@nokia.com)
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial Usage
 ** Licensees holding valid Qt Commercial licenses may use this file in
 ** accordance with the Qt Commercial License Agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Nokia.
 **
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License versions 2.0 or 3.0 as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file.  Please review the following information
-** to ensure GNU General Public Licensing requirements will be met:
-** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
-** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
-** exception, Nokia gives you certain additional rights. These rights
-** are described in the Nokia Qt GPL Exception version 1.3, included in
-** the file GPL_EXCEPTION.txt in this package.
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Qt for Windows(R) Licensees
-** As a special exception, Nokia, as the sole copyright holder for Qt
-** Designer, grants users of the Qt/Eclipse Integration plug-in the
-** right for the Qt/Eclipse Integration to link to functionality
-** provided by Qt Designer and its related libraries.
-**
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -46,7 +50,7 @@
 #include <QtNetwork/QSslCipher>
 
 SslClient::SslClient(QWidget *parent)
-    : QWidget(parent), socket(0), padLock(0)
+    : QWidget(parent), socket(0), padLock(0), executingDialog(false)
 {
     form = new Ui_Form;
     form->setupUi(this);
@@ -106,6 +110,9 @@ void SslClient::secureConnect()
 
 void SslClient::socketStateChanged(QAbstractSocket::SocketState state)
 {
+    if (executingDialog)
+        return;
+
     updateEnabledState();
     if (state == QAbstractSocket::UnconnectedState) {
         form->hostNameEdit->setPalette(QPalette());
@@ -120,6 +127,9 @@ void SslClient::socketStateChanged(QAbstractSocket::SocketState state)
 
 void SslClient::socketEncrypted()
 {
+    if (!socket)
+        return;                 // might have disconnected already
+
     form->sessionOutput->clear();
     form->sessionInput->setFocus();
 
@@ -181,8 +191,14 @@ void SslClient::sslErrors(const QList<QSslError> &errors)
     foreach (const QSslError &error, errors)
         ui.sslErrorList->addItem(error.errorString());
 
+    executingDialog = true;
     if (errorDialog.exec() == QDialog::Accepted)
         socket->ignoreSslErrors();
+    executingDialog = false;
+
+    // did the socket state change?
+    if (socket->state() != QAbstractSocket::ConnectedState)
+        socketStateChanged(socket->state());
 }
 
 void SslClient::displayCertificateInfo()
