@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -45,8 +43,11 @@
 
 #include "imagecomposer.h"
 
+//! [0]
 static const QSize resultSize(200, 200);
+//! [0]
 
+//! [1]
 ImageComposer::ImageComposer()
 {
     sourceButton = new QToolButton;
@@ -65,7 +66,21 @@ ImageComposer::ImageComposer()
     addOp(QPainter::CompositionMode_SourceAtop, tr("SourceAtop"));
     addOp(QPainter::CompositionMode_DestinationAtop, tr("DestinationAtop"));
     addOp(QPainter::CompositionMode_Xor, tr("Xor"));
+    addOp(QPainter::CompositionMode_Plus, tr("Plus"));
+    addOp(QPainter::CompositionMode_Multiply, tr("Multiply"));
+    addOp(QPainter::CompositionMode_Screen, tr("Screen"));
+    addOp(QPainter::CompositionMode_Overlay, tr("Overlay"));
+    addOp(QPainter::CompositionMode_Darken, tr("Darken"));
+    addOp(QPainter::CompositionMode_Lighten, tr("Lighten"));
+    addOp(QPainter::CompositionMode_ColorDodge, tr("ColorDodge"));
+    addOp(QPainter::CompositionMode_ColorBurn, tr("ColorBurn"));
+    addOp(QPainter::CompositionMode_HardLight, tr("HardLight"));
+    addOp(QPainter::CompositionMode_SoftLight, tr("SoftLight"));
+    addOp(QPainter::CompositionMode_Difference, tr("Difference"));
+    addOp(QPainter::CompositionMode_Exclusion, tr("Exclusion"));
+//! [1]
 
+//! [2]
     destinationButton = new QToolButton;
     destinationButton->setIconSize(resultSize);
 
@@ -73,13 +88,17 @@ ImageComposer::ImageComposer()
 
     resultLabel = new QLabel;
     resultLabel->setMinimumWidth(resultSize.width());
+//! [2]
 
+//! [3]
     connect(sourceButton, SIGNAL(clicked()), this, SLOT(chooseSource()));
     connect(operatorComboBox, SIGNAL(activated(int)),
             this, SLOT(recalculateResult()));
     connect(destinationButton, SIGNAL(clicked()),
             this, SLOT(chooseDestination()));
+//! [3]
 
+//! [4]
     QGridLayout *mainLayout = new QGridLayout;
     mainLayout->addWidget(sourceButton, 0, 0, 3, 1);
     mainLayout->addWidget(operatorComboBox, 1, 1);
@@ -88,7 +107,9 @@ ImageComposer::ImageComposer()
     mainLayout->addWidget(resultLabel, 0, 4, 3, 1);
     mainLayout->setSizeConstraint(QLayout::SetFixedSize);
     setLayout(mainLayout);
+//! [4]
 
+//! [5]
     resultImage = QImage(resultSize, QImage::Format_ARGB32_Premultiplied);
 
     loadImage(":/images/butterfly.png", &sourceImage, sourceButton);
@@ -96,18 +117,24 @@ ImageComposer::ImageComposer()
 
     setWindowTitle(tr("Image Composition"));
 }
+//! [5]
 
+//! [6]
 void ImageComposer::chooseSource()
 {
     chooseImage(tr("Choose Source Image"), &sourceImage, sourceButton);
 }
+//! [6]
 
+//! [7]
 void ImageComposer::chooseDestination()
 {
     chooseImage(tr("Choose Destination Image"), &destinationImage,
                 destinationButton);
 }
+//! [7]
 
+//! [8]
 void ImageComposer::recalculateResult()
 {
     QPainter::CompositionMode mode = currentMode();
@@ -125,12 +152,16 @@ void ImageComposer::recalculateResult()
 
     resultLabel->setPixmap(QPixmap::fromImage(resultImage));
 }
+//! [8]
 
+//! [9]
 void ImageComposer::addOp(QPainter::CompositionMode mode, const QString &name)
 {
     operatorComboBox->addItem(name, mode);
 }
+//! [9]
 
+//! [10]
 void ImageComposer::chooseImage(const QString &title, QImage *image,
                                 QToolButton *button)
 {
@@ -138,7 +169,9 @@ void ImageComposer::chooseImage(const QString &title, QImage *image,
     if (!fileName.isEmpty())
         loadImage(fileName, image, button);
 }
+//! [10]
 
+//! [11]
 void ImageComposer::loadImage(const QString &fileName, QImage *image,
                               QToolButton *button)
 {
@@ -157,15 +190,20 @@ void ImageComposer::loadImage(const QString &fileName, QImage *image,
 
     recalculateResult();
 }
+//! [11]
 
+//! [12]
 QPainter::CompositionMode ImageComposer::currentMode() const
 {
     return (QPainter::CompositionMode)
            operatorComboBox->itemData(operatorComboBox->currentIndex()).toInt();
 }
+//! [12]
 
+//! [13]
 QPoint ImageComposer::imagePos(const QImage &image) const
 {
     return QPoint((resultSize.width() - image.width()) / 2,
                   (resultSize.height() - image.height()) / 2);
 }
+//! [13]
