@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -39,6 +44,7 @@
 #include "detailsdialog.h"
 #include "mainwindow.h"
 
+//! [0]
 MainWindow::MainWindow()
 {
     QMenu *fileMenu = new QMenu(tr("&File"), this);
@@ -59,7 +65,9 @@ MainWindow::MainWindow()
     setCentralWidget(letters);
     setWindowTitle(tr("Order Form"));
 }
+//! [0]
 
+//! [1]
 void MainWindow::createLetter(const QString &name, const QString &address,
                               QList<QPair<QString,int> > orderItems,
                               bool sendOffers)
@@ -67,9 +75,12 @@ void MainWindow::createLetter(const QString &name, const QString &address,
     QTextEdit *editor = new QTextEdit;
     int tabIndex = letters->addTab(editor, name);
     letters->setCurrentIndex(tabIndex);
+//! [1]
 
+//! [2]
     QTextCursor cursor(editor->textCursor());
     cursor.movePosition(QTextCursor::Start);
+//! [2] //! [3]
     QTextFrame *topFrame = cursor.currentFrame();
     QTextFrameFormat topFrameFormat = topFrame->frameFormat();
     topFrameFormat.setPadding(16);
@@ -93,7 +104,9 @@ void MainWindow::createLetter(const QString &name, const QString &address,
     cursor.insertText("Industry Park");
     cursor.insertBlock();
     cursor.insertText("Another country");
+//! [3]
 
+//! [4]
     cursor.setPosition(topFrame->lastPosition());
 
     cursor.insertText(name, textFormat);
@@ -102,6 +115,7 @@ void MainWindow::createLetter(const QString &name, const QString &address,
         cursor.insertBlock();
         cursor.insertText(line);
     }
+//! [4] //! [5]
     cursor.insertBlock();
     cursor.insertBlock();
 
@@ -113,12 +127,17 @@ void MainWindow::createLetter(const QString &name, const QString &address,
     QTextFrameFormat bodyFrameFormat;
     bodyFrameFormat.setWidth(QTextLength(QTextLength::PercentageLength, 100));
     cursor.insertFrame(bodyFrameFormat);
+//! [5]
 
+//! [6]
     cursor.insertText(tr("I would like to place an order for the following "
                          "items:"), textFormat);
     cursor.insertBlock();
+//! [6] //! [7]
     cursor.insertBlock();
+//! [7]
 
+//! [8]
     QTextTableFormat orderTableFormat;
     orderTableFormat.setAlignment(Qt::AlignHCenter);
     QTextTable *orderTable = cursor.insertTable(1, 2, orderTableFormat);
@@ -126,12 +145,16 @@ void MainWindow::createLetter(const QString &name, const QString &address,
     QTextFrameFormat orderFrameFormat = cursor.currentFrame()->frameFormat();
     orderFrameFormat.setBorder(1);
     cursor.currentFrame()->setFrameFormat(orderFrameFormat);
+//! [8]
 
+//! [9]
     cursor = orderTable->cellAt(0, 0).firstCursorPosition();
     cursor.insertText(tr("Product"), boldFormat);
     cursor = orderTable->cellAt(0, 1).firstCursorPosition();
     cursor.insertText(tr("Quantity"), boldFormat);
+//! [9]
 
+//! [10]
     for (int i = 0; i < orderItems.count(); ++i) {
         QPair<QString,int> item = orderItems[i];
         int row = orderTable->rows();
@@ -142,14 +165,19 @@ void MainWindow::createLetter(const QString &name, const QString &address,
         cursor = orderTable->cellAt(row, 1).firstCursorPosition();
         cursor.insertText(QString("%1").arg(item.second), textFormat);
     }
+//! [10]
 
+//! [11]
     cursor.setPosition(topFrame->lastPosition());
 
     cursor.insertBlock();
+//! [11] //! [12]
     cursor.insertText(tr("Please update my records to take account of the "
                          "following privacy information:"));
     cursor.insertBlock();
+//! [12]
 
+//! [13]
     QTextTable *offersTable = cursor.insertTable(2, 2);
 
     cursor = offersTable->cellAt(0, 1).firstCursorPosition();
@@ -165,7 +193,9 @@ void MainWindow::createLetter(const QString &name, const QString &address,
         cursor = offersTable->cellAt(1, 0).firstCursorPosition();
 
     cursor.insertText("X", boldFormat);
+//! [13]
 
+//! [14]
     cursor.setPosition(topFrame->lastPosition());
     cursor.insertBlock();
     cursor.insertText(tr("Sincerely,"), textFormat);
@@ -176,14 +206,18 @@ void MainWindow::createLetter(const QString &name, const QString &address,
 
     printAction->setEnabled(true);
 }
+//! [14]
 
+//! [15]
 void MainWindow::createSample()
 {
     DetailsDialog dialog("Dialog with default values", this);
     createLetter("Mr. Smith", "12 High Street\nSmall Town\nThis country",
                  dialog.orderItems(), true);
 }
+//! [15]
 
+//! [16]
 void MainWindow::openDialog()
 {
     DetailsDialog dialog(tr("Enter Customer Details"), this);
@@ -192,10 +226,14 @@ void MainWindow::openDialog()
         createLetter(dialog.senderName(), dialog.senderAddress(),
                      dialog.orderItems(), dialog.sendOffers());
 }
+//! [16]
 
+//! [17]
 void MainWindow::printFile()
 {
+#ifndef QT_NO_PRINTER
     QTextEdit *editor = static_cast<QTextEdit*>(letters->currentWidget());
+//! [18]
     QPrinter printer;
 
     QPrintDialog *dialog = new QPrintDialog(&printer, this);
@@ -204,6 +242,9 @@ void MainWindow::printFile()
         dialog->addEnabledOption(QAbstractPrintDialog::PrintSelection);
     if (dialog->exec() != QDialog::Accepted)
         return;
+//! [18]
 
     editor->print(&printer);
+#endif
 }
+//! [17]
