@@ -1,52 +1,52 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "informationwindow.h"
 
+//! [0]
 InformationWindow::InformationWindow(int id, QSqlRelationalTableModel *offices,
                                      QWidget *parent)
     : QDialog(parent)
 {
+//! [0] //! [1]
     QLabel *locationLabel = new QLabel(tr("Location: "));
     QLabel *countryLabel = new QLabel(tr("Country: "));
     QLabel *descriptionLabel = new QLabel(tr("Description: "));
@@ -57,21 +57,27 @@ InformationWindow::InformationWindow(int id, QSqlRelationalTableModel *offices,
     locationText = new QLabel;
     countryText = new QLabel;
     descriptionEditor = new QTextEdit;
+//! [1]
 
+//! [2]
     imageFileEditor = new QComboBox;
     imageFileEditor->setModel(offices->relationModel(1));
     imageFileEditor->setModelColumn(offices->relationModel(1)->fieldIndex("file"));
+//! [2]
 
+//! [3]
     mapper = new QDataWidgetMapper(this);
     mapper->setModel(offices);
     mapper->setSubmitPolicy(QDataWidgetMapper::ManualSubmit);
     mapper->setItemDelegate(new QSqlRelationalDelegate(mapper));
     mapper->addMapping(imageFileEditor, 1);
-    mapper->addMapping(locationText, 2);
-    mapper->addMapping(countryText, 3);
+    mapper->addMapping(locationText, 2, "text");
+    mapper->addMapping(countryText, 3, "text");
     mapper->addMapping(descriptionEditor, 4);
     mapper->setCurrentIndex(id);
+//! [3]
 
+//! [4]
     connect(descriptionEditor, SIGNAL(textChanged()),
             this, SLOT(enableButtons()));
     connect(imageFileEditor, SIGNAL(currentIndexChanged(int)),
@@ -94,21 +100,27 @@ InformationWindow::InformationWindow(int id, QSqlRelationalTableModel *offices,
 
     setWindowFlags(Qt::Window);
     enableButtons(false);
-    setWindowTitle(tr("Trolltech Office: %1").arg(locationText->text()));
+    setWindowTitle(tr("Office: %1").arg(locationText->text()));
     resize(320, sizeHint().height());
 }
+//! [4]
 
+//! [5]
 int InformationWindow::id()
 {
     return locationId;
 }
+//! [5]
 
+//! [6]
 void InformationWindow::revert()
 {
     mapper->revert();
     enableButtons(false);
 }
+//! [6]
 
+//! [7]
 void InformationWindow::submit()
 {
     QString newImage(imageFileEditor->currentText());
@@ -123,7 +135,9 @@ void InformationWindow::submit()
 
     enableButtons(false);
 }
+//! [7]
 
+//! [8]
 void InformationWindow::createButtons()
 {
     closeButton = new QPushButton(tr("&Close"));
@@ -135,17 +149,22 @@ void InformationWindow::createButtons()
     connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
     connect(revertButton, SIGNAL(clicked()), this, SLOT(revert()));
     connect(submitButton, SIGNAL(clicked()), this, SLOT(submit()));
+//! [8]
 
+//! [9]
     buttonBox = new QDialogButtonBox;
     buttonBox->addButton(submitButton, QDialogButtonBox::ResetRole);
     buttonBox->addButton(revertButton, QDialogButtonBox::ResetRole);
     buttonBox->addButton(closeButton, QDialogButtonBox::RejectRole);
 }
+//! [9]
 
+//! [10]
 void InformationWindow::enableButtons(bool enable)
 {
     revertButton->setEnabled(enable);
     submitButton->setEnabled(enable);
 }
+//! [10]
 
 
