@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -50,18 +48,23 @@
 
 const float Pi = 3.14159f;
 
+//! [0]
 QStringList BasicToolsPlugin::brushes() const
 {
     return QStringList() << tr("Pencil") << tr("Air Brush")
                          << tr("Random Letters");
 }
+//! [0]
 
+//! [1]
 QRect BasicToolsPlugin::mousePress(const QString &brush, QPainter &painter,
                                    const QPoint &pos)
 {
     return mouseMove(brush, painter, pos, pos);
 }
+//! [1]
 
+//! [2]
 QRect BasicToolsPlugin::mouseMove(const QString &brush, QPainter &painter,
                                   const QPoint &oldPos, const QPoint &newPos)
 {
@@ -73,6 +76,7 @@ QRect BasicToolsPlugin::mouseMove(const QString &brush, QPainter &painter,
     QColor color = painter.pen().color();
     int thickness = painter.pen().width();
     QColor transparentColor(color.red(), color.green(), color.blue(), 0);
+//! [2] //! [3]
 
     if (brush == tr("Pencil")) {
         painter.drawLine(oldPos, newPos);
@@ -107,19 +111,25 @@ QRect BasicToolsPlugin::mouseMove(const QString &brush, QPainter &painter,
     painter.restore();
     return boundingRect;
 }
+//! [3]
 
+//! [4]
 QRect BasicToolsPlugin::mouseRelease(const QString & /* brush */,
                                      QPainter & /* painter */,
                                      const QPoint & /* pos */)
 {
     return QRect(0, 0, 0, 0);
 }
+//! [4]
 
+//! [5]
 QStringList BasicToolsPlugin::shapes() const
 {
     return QStringList() << tr("Circle") << tr("Star") << tr("Text...");
 }
+//! [5]
 
+//! [6]
 QPainterPath BasicToolsPlugin::generateShape(const QString &shape,
                                              QWidget *parent)
 {
@@ -147,13 +157,17 @@ QPainterPath BasicToolsPlugin::generateShape(const QString &shape,
 
     return path;
 }
+//! [6]
 
+//! [7]
 QStringList BasicToolsPlugin::filters() const
 {
     return QStringList() << tr("Invert Pixels") << tr("Swap RGB")
                          << tr("Grayscale");
 }
+//! [7]
 
+//! [8]
 QImage BasicToolsPlugin::filterImage(const QString &filter, const QImage &image,
                                      QWidget * /* parent */)
 {
@@ -175,5 +189,10 @@ QImage BasicToolsPlugin::filterImage(const QString &filter, const QImage &image,
     }
     return result;
 }
+//! [8]
 
+QT_BEGIN_NAMESPACE
+//! [9]
 Q_EXPORT_PLUGIN2(pnp_basictools, BasicToolsPlugin)
+//! [9]
+QT_END_NAMESPACE
