@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -152,32 +170,32 @@ void MoviePlayer::createButtons()
     QSize iconSize(36, 36);
 
     openButton = new QToolButton;
-    openButton->setIcon(QIcon(":/images/open.png"));
+    openButton->setIcon(style()->standardIcon(QStyle::SP_DialogOpenButton));
     openButton->setIconSize(iconSize);
     openButton->setToolTip(tr("Open File"));
     connect(openButton, SIGNAL(clicked()), this, SLOT(open()));
 
     playButton = new QToolButton;
-    playButton->setIcon(QIcon(":/images/play.png"));
+    playButton->setIcon(style()->standardIcon(QStyle::SP_MediaPlay));
     playButton->setIconSize(iconSize);
     playButton->setToolTip(tr("Play"));
     connect(playButton, SIGNAL(clicked()), movie, SLOT(start()));
 
     pauseButton = new QToolButton;
     pauseButton->setCheckable(true);
-    pauseButton->setIcon(QIcon(":/images/pause.png"));
+    pauseButton->setIcon(style()->standardIcon(QStyle::SP_MediaPause));
     pauseButton->setIconSize(iconSize);
     pauseButton->setToolTip(tr("Pause"));
     connect(pauseButton, SIGNAL(clicked(bool)), movie, SLOT(setPaused(bool)));
 
     stopButton = new QToolButton;
-    stopButton->setIcon(QIcon(":/images/stop.png"));
+    stopButton->setIcon(style()->standardIcon(QStyle::SP_MediaStop));
     stopButton->setIconSize(iconSize);
     stopButton->setToolTip(tr("Stop"));
     connect(stopButton, SIGNAL(clicked()), movie, SLOT(stop()));
 
     quitButton = new QToolButton;
-    quitButton->setIcon(QIcon(":/images/quit.png"));
+    quitButton->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
     quitButton->setIconSize(iconSize);
     quitButton->setToolTip(tr("Quit"));
     connect(quitButton, SIGNAL(clicked()), this, SLOT(close()));
