@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -38,8 +43,9 @@
 
 #include "shapedclock.h"
 
+//! [0]
 ShapedClock::ShapedClock(QWidget *parent)
-    : QWidget(parent, Qt::FramelessWindowHint)
+    : QWidget(parent, Qt::FramelessWindowHint | Qt::WindowSystemMenuHint)
 {
     QTimer *timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), this, SLOT(update()));
@@ -55,7 +61,9 @@ ShapedClock::ShapedClock(QWidget *parent)
                   "Use the right mouse button to open a context menu."));
     setWindowTitle(tr("Shaped Analog Clock"));
 }
+//! [0]
 
+//! [1]
 void ShapedClock::mousePressEvent(QMouseEvent *event)
 {
     if (event->button() == Qt::LeftButton) {
@@ -63,7 +71,9 @@ void ShapedClock::mousePressEvent(QMouseEvent *event)
         event->accept();
     }
 }
+//! [1]
 
+//! [2]
 void ShapedClock::mouseMoveEvent(QMouseEvent *event)
 {
     if (event->buttons() & Qt::LeftButton) {
@@ -71,7 +81,9 @@ void ShapedClock::mouseMoveEvent(QMouseEvent *event)
         event->accept();
     }
 }
+//! [2]
 
+//! [3]
 void ShapedClock::paintEvent(QPaintEvent *)
 {
     static const QPoint hourHand[3] = {
@@ -127,7 +139,9 @@ void ShapedClock::paintEvent(QPaintEvent *)
         painter.rotate(6.0);
     }
 }
+//! [3]
 
+//! [4]
 void ShapedClock::resizeEvent(QResizeEvent * /* event */)
 {
     int side = qMin(width(), height());
@@ -135,8 +149,11 @@ void ShapedClock::resizeEvent(QResizeEvent * /* event */)
                          side, QRegion::Ellipse);
     setMask(maskedRegion);
 }
+//! [4]
 
+//! [5]
 QSize ShapedClock::sizeHint() const
 {
     return QSize(100, 100);
 }
+//! [5]
