@@ -1,37 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
-** Contact: Qt Software Information (qt-info@nokia.com)
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial Usage
 ** Licensees holding valid Qt Commercial licenses may use this file in
 ** accordance with the Qt Commercial License Agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Nokia.
 **
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License versions 2.0 or 3.0 as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file.  Please review the following information
-** to ensure GNU General Public Licensing requirements will be met:
-** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
-** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
-** exception, Nokia gives you certain additional rights. These rights
-** are described in the Nokia Qt GPL Exception version 1.3, included in
-** the file GPL_EXCEPTION.txt in this package.
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Qt for Windows(R) Licensees
-** As a special exception, Nokia, as the sole copyright holder for Qt
-** Designer, grants users of the Qt/Eclipse Integration plug-in the
-** right for the Qt/Eclipse Integration to link to functionality
-** provided by Qt Designer and its related libraries.
-**
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -43,11 +47,10 @@
 //! [0]
 TabletCanvas::TabletCanvas()
 {
+    resize(500, 500);
     myBrush = QBrush();
     myPen = QPen();
-    image = QImage(500, 500, QImage::Format_ARGB32);
-    QPainter painter(&image);
-    painter.fillRect(0, 0, 499, 499, Qt::white);
+    initImage();
     setAutoFillBackground(true);
     deviceDown = false;
     myColor = Qt::red;
@@ -56,6 +59,17 @@ TabletCanvas::TabletCanvas()
     colorSaturationType = NoSaturation;
     lineWidthType = LineWidthPressure;
 }
+
+void TabletCanvas::initImage()
+{
+    QImage newImage = QImage(width(), height(), QImage::Format_ARGB32);
+    QPainter painter(&newImage);
+    painter.fillRect(0, 0, newImage.width(), newImage.height(), Qt::white);
+    if (!image.isNull())
+        painter.drawImage(0, 0, image);
+    painter.end();
+    image = newImage;
+}
 //! [0]
 
 //! [1]
@@ -139,8 +153,13 @@ void TabletCanvas::paintImage(QPainter &painter, QTabletEvent *event)
                                     polyLine[i] + brushAdjust));
             }
             break;
+        case QTabletEvent::Puck:
+        case QTabletEvent::FourDMouse:
+        case QTabletEvent::RotationStylus:
+            qWarning("This input device is not supported by the example.");
+            break;
         default:
-            qWarning("Unsupported tablet device.");
+            qWarning("Unknown tablet device.");
     }
 }
 //! [5]
@@ -230,3 +249,9 @@ void TabletCanvas::updateBrush(QTabletEvent *event)
     }
 }
 //! [11]
+
+void TabletCanvas::resizeEvent(QResizeEvent *event)
+{
+    initImage();
+    polyLine[0] = polyLine[1] = polyLine[2] = QPoint();
+}
